@@ -86,6 +86,10 @@ def get_settings(environment: Optional[str], log_level: str):
             "datasource_data_risk_url": os.getenv(
                 "SNATCH_DATASOURCE_DATA_RISK_URL", "http://datasource_data_risk"
             ),
+            "protest_secret_token": os.getenv("SNATCH_PROTEST_SECRET_TOKEN", "foo"),
+            "datasource_protest_url": os.getenv(
+                "SNATCH_DATASOURCE_PROTEST_URL", "http://datasource_data_risk"
+            ),
         }
     }
     config.update(
